@@ -373,7 +373,7 @@ class PackageConfig
     paths << (pkg_config_prefix + "libx32/pkgconfig").to_s
     paths << (pkg_config_prefix + "lib/pkgconfig").to_s
     paths << (pkg_config_prefix + "libdata/pkgconfig").to_s
-    if /-darwin\d+\z/ =~ RUBY_PLATFORM and
+    if /-darwin\d[\d\.]*\z/ =~ RUBY_PLATFORM and
         /\A(\d+\.\d+)/ =~ `sw_vers -productVersion`
       mac_os_version = $1
       homebrew_repository_candidates = []
